import { BedrockModel } from './bedrock-model';

export type ClaudeMessageContent = {
    type: 'text' | 'image';
    text?: string;
    source?: {
        type: 'base64';
        media_type: 'image/png' | 'image/jpeg';
        data: string;
    };
};

export type ClaudeMessage = {
    role: 'user' | 'assistant';
    content: ClaudeMessageContent[];
};

export type ClaudeThinkingParams = {
    enabled: boolean;
    budgetTokens: number;
};

export type ClaudeResponseContent = {
    type: 'text' | 'thinking';
    thinking?: string;
    text?: string;
};

export type ClaudeResponse = {
    usage: {
        inputTokens: number;
        outputTokens: number;
    };
    content: ClaudeResponseContent[];
};

export class ClaudeApi {
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockModel,
    );

    public invoke(
        messages: ClaudeMessage[],
        temperature?: number,
        maxTokens?: number,
        system?: string,
        thinking?: ClaudeThinkingParams,
    ): Promise<ClaudeResponse>;
}
