import { BedrockModel } from './bedrock-model';

export type NovaContent = {
    text?: string;
    image?: {
        format: 'png' | 'jpeg' | 'gif' | 'webp';
        source: { bytes: Uint8Array };
    };
};

export type NovaMessage = {
    role?: 'user' | 'assistant';
    content: NovaContent[];
};

export type NovaResponseContent = {
    text?: string;
};

export type NovaResponse = {
    usage: {
        inputTokens: number;
        outputTokens: number;
    };
    content: NovaResponseContent[];
};

export class NovaApi {
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockModel,
    );

    public invoke(
        messages: NovaMessage[],
        temperature?: number,
        maxTokens?: number,
        topP?: number,
        systemPrompt?: string
    ): Promise<NovaResponse>;
}